@@ -88,7 +88,7 @@ class FilteredWebSocketFactory(Factory):
 
 def build_reactor(options, **kwargs):
     web_socket_instance = FilteredWebSocketFactory(**kwargs)
-    pubsub_listener = kwargs.pop("pubsub_listener", None)
+    subscriber = kwargs.pop("subscriber", None)
 
     if options.key and options.cert:
         with open(options.key) as keyFile:
@@ -100,15 +100,15 @@ def build_reactor(options, **kwargs):
             options.port,
             web_socket_instance
         )
-    if pubsub_listener is not None:
+    if subscriber is not None:
         reactor.callInThread(
-            pubsub_listener.listener,
+            subscriber.listener,
             web_socket_instance
         )
         reactor.addSystemEventTrigger(
             "before",
             "shutdown",
-            pubsub_listener.kill
+            subscriber.kill
         )
 
     # Start the consumer loop
@@ -148,60 +148,3 @@ def default_parser():
         help="A certificate file (ssl)."
     )
     return parser
-
-
-if __name__ == '__main__':
-    import os
-    import importlib
-
-    from . import config_deserializer
-    from .storage_objects.base import BasePubSubStorageObject
-
-    # Storage objects are configured via env variables for now,
-    # consider .conf files in the future
-    STORAGE_OBJECT_MODULE = os.environ.get("STORAGE_OBJECT_MODULE", None)
-    if STORAGE_OBJECT_MODULE is None:
-        STORAGE_OBJECT_MODULE = \
-            "filtered_websocket.storage_objects.default"
-
-    storage_object = importlib.import_module(STORAGE_OBJECT_MODULE)
-    StorageObject = storage_object.StorageObject  # NOQA
-
-    parser = default_parser()
-    parser = StorageObject.parser(parser)
-    options = parser.parse_args(sys.argv[1:])
-
-    # A passed in config file will overwrite all other args
-    if options.config is not None:
-        options = parser.parse_args(config_deserializer(options.config))
-
-    # If no filters are specified this will be imported.
-    # the broadcast_by_message filter just creates a simple broadcast server
-    FILTERS = [
-        "filtered_websocket.filters.broadcast_messages",
-        "filtered_websocket.filters.stdout_messages",
-    ]
-
-    storage_object_instance = StorageObject(options)
-    if issubclass(StorageObject, BasePubSubStorageObject):
-        storage_object_listener = StorageObject.get_pubsub_listener()(
-            client=storage_object_instance.get_client(),
-            options=options,
-        )
-        # Build our server reactor.
-        web_socket_instance = build_reactor(
-            options,
-            storage_object=storage_object_instance,
-            pubsub_listener=storage_object_listener
-        )
-    else:
-        build_reactor(options)
-
-    if options.filters is not None:
-        FILTERS = options.filters
-
-    # Importing the filters will inject them into event handlers at runtime
-    for _filter in FILTERS:
-        importlib.import_module(_filter)
-
-    reactor.run()
