@@ -1,7 +1,7 @@
 class BaseStorageObject(object):
 
     def __init__(self, options, *args, **kwargs):
-        self.options = options  # argparse options
+        self.options = options  # Namespace object
         self.storage = None
 
     def get(self, item):
@@ -16,6 +16,13 @@ class BaseStorageObject(object):
     def remove(self, key, value):
         raise NotImplementedError
 
+    @classmethod
+    def parser(cls, parser):
+        """
+        Intended for attaching additional arguments to an ArgumentParser.
+        """
+        return parser
+
 
 class BasePubSubStorageObject(BaseStorageObject):
     """
@@ -33,9 +40,9 @@ class BasePubSubStorageObject(BaseStorageObject):
         raise NotImplementedError
 
     @classmethod
-    def get_pubsub_listener(cls):
+    def get_subscriber(cls):
         """
-        Return some class which implements a 'listener' method.
-        All listeners should take a an opt
+        Return some class which inherits from:
+        filtered_websocket.storage_objects.subscribers.base.BaseSubscriber
         """
         raise NotImplementedError
